Dir

Struct Dir 

pub struct Dir { /* private fields */ }
Available on crate feature fs only.
A reference to an open directory on a filesystem.

Platform specific

  • Windows: the operations are forwarded to cap-primitives. They will treat self as the root of the filesystem.
  • Unix: the operatiosn are forwarded to syscalls directly. They don’t limit the path to be under self. If the path is absolute, the directory represented by self will be ignored.

Implementations

Source

impl Dir

pub async fn open(path: impl AsRef<Path>) -> Result<Dir, Error>

Opens a directory at the specified path and returns a reference to it.

pub async fn open_file_with( &self, path: impl AsRef<Path>, options: &OpenOptions, ) -> Result<File, Error>

Opens a file at path with the options specified by options.

pub async fn open_file(&self, path: impl AsRef<Path>) -> Result<File, Error>

Attempts to open a file in read-only mode.

pub async fn create_file(&self, path: impl AsRef<Path>) -> Result<File, Error>

Opens a file in write-only mode.

pub async fn open_dir(&self, path: impl AsRef<Path>) -> Result<Dir, Error>

Attempts to open a directory.

pub async fn create_dir_with( &self, path: impl AsRef<Path>, builder: &DirBuilder, ) -> Result<(), Error>

Creates the specified directory with the options configured in this builder.

pub async fn create_dir(&self, path: impl AsRef<Path>) -> Result<(), Error>

Creates a new, empty directory at the provided path.

pub async fn create_dir_all(&self, path: impl AsRef<Path>) -> Result<(), Error>

Recursively create a directory and all of its parent components if they are missing.

pub async fn dir_metadata(&self) -> Result<Metadata, Error>

Queries metadata about the underlying directory.

pub async fn metadata(&self, path: impl AsRef<Path>) -> Result<Metadata, Error>

Given a path, query the file system to get information about a file, directory, etc.

Query the metadata about a file without following symlinks.

Creates a new hard link on a filesystem.

Available on Unix only.

Creates a new symbolic link on a filesystem.

The original argument provides the target of the symlink. The link argument provides the name of the created symlink.

Despite the argument ordering, original is not resolved relative to self here. link is resolved relative to self, and original is not resolved within this function.

pub async fn rename( &self, from: impl AsRef<Path>, to_dir: &Dir, to: impl AsRef<Path>, ) -> Result<(), Error>

Rename a file or directory to a new name, replacing the original file if it already exists.

pub async fn remove_file(&self, path: impl AsRef<Path>) -> Result<(), Error>

Removes a file from a filesystem.

pub async fn remove_dir(&self, path: impl AsRef<Path>) -> Result<(), Error>

Removes an empty directory.

pub async fn read(&self, path: impl AsRef<Path>) -> Result<Vec<u8>, Error>

Read the entire contents of a file into a bytes vector.

pub async fn write<B>(&self, path: impl AsRef<Path>, buf: B) -> BufResult<(), B>
where B: IoBuf,

Write a buffer as the entire contents of a file.